@@ -10,6 +10,7 @@ def rings(features_X, features_position, criteria="k", max_radios=[200, 300, 400
     Luego, toma los K vecinos más cercanos a cada pundo donde K
     está definido según "max_neighbors_per_radio".
     """
+    original_radios = max_radios
     meter_to_degree_equivalence = 9.090909091e-6
     max_radios = np.array(max_radios)*meter_to_degree_equivalence # Se transforma de metros a grados
     features_X = data_format(features_X)
@@ -37,7 +38,7 @@ def rings(features_X, features_position, criteria="k", max_radios=[200, 300, 400
                 final_features_df[f"{feature}_{k}nb"] = features_array[f_index] # indico cuantos vecinos en el nombre del attributo
         features_X = final_features_df
     elif(criteria == "r"):
-        for _, r in enumerate(max_radios):
+        for i, r in enumerate(max_radios):
             features_array = [ [] for _ in range(len_features)]
             nearest_neighbours = tree.query_ball_tree(tree, r) # vecinos dentro de radio r
             for _, neighbourhood in enumerate(nearest_neighbours):
@@ -46,7 +47,7 @@ def rings(features_X, features_position, criteria="k", max_radios=[200, 300, 400
                     mean_feature = subset_feature.mean()
                     features_array[f_index].append(mean_feature) 
             for f_index, feature in enumerate(features_X.columns):
-                final_features_df[f"{feature}_{r}m"] = features_array[f_index]
+                final_features_df[f"{feature}_{original_radios[i]}m"] = features_array[f_index]
         features_X = final_features_df
     elif(criteria == "rk"):
         for i, r in enumerate(max_radios):
@@ -71,7 +72,7 @@ def rings(features_X, features_position, criteria="k", max_radios=[200, 300, 400
                     features_array[f_index].append(mean_feature) 
             
             for f_index, feature in enumerate(features_X.columns):
-                final_features_df[f"{feature}_{r}m{k}nb"] = features_array[f_index]
+                final_features_df[f"{feature}_{original_radios[i]}m{k}nb"] = features_array[f_index]
         features_X = final_features_df
     return features_X
 
